#!/usr/bin/env node
'use strict';

require('dotenv/config');
var cac = require('cac');
var consola = require('consola');
var googleFontMetadata = require('google-font-metadata');
var colors = require('picocolors');
var queue = require('./queue-8fd8aeeb.cjs');
var fs = require('fs-extra');
var path = require('pathe');
require('@clack/prompts');
require('json-stringify-pretty-compact');
require('@fontsource-utils/generate');
require('node:fs');
require('p-queue');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var consola__default = /*#__PURE__*/_interopDefaultLegacy(consola);
var colors__default = /*#__PURE__*/_interopDefaultLegacy(colors);
var fs__default = /*#__PURE__*/_interopDefaultLegacy(fs);
var path__default = /*#__PURE__*/_interopDefaultLegacy(path);

var version = "0.3.13";

const getMetadata = async (dir) => {
  return await fs__default["default"].readJson(path__default["default"].join(dir, "metadata.json"), "utf8");
};
const getPackageJson = async (dir) => {
  return await fs__default["default"].readJson(path__default["default"].join(dir, "package.json"), "utf8");
};
const rebuild = async (opts) => {
  const dir = "./fonts/other";
  const directories = queue.getDirectories(dir, opts?.cwd);
  for (const directory of directories) {
    const fontDir = path__default["default"].join(opts?.cwd ?? process.cwd(), dir, directory);
    const metadata = await getMetadata(fontDir);
    const pkgJson = await getPackageJson(fontDir);
    const files = await fs__default["default"].readdir(fontDir);
    for (const file of files) {
      if (file !== "files" && file !== "LICENSE") {
        await fs__default["default"].remove(path__default["default"].join(fontDir, file));
      }
    }
    await queue.buildCustom(metadata, {
      dir,
      version: pkgJson.version,
      publishHash: pkgJson.publishHash
    });
    consola.consola.info(`Rebuilt ${metadata.id}.`);
  }
  await queue.verifyAll();
};

const cli = cac.cac("fontsource");
cli.command("fetch [key]", "Fetch parsing metadata for all fonts").option("-f, --force", "Force parse all metadata").action(async (key, options) => {
  try {
    const finalKey = key ?? process.env.GOOGLE_API_KEY;
    if (!finalKey) {
      throw new Error("No API key provided.");
    }
    if (options.force) {
      consola__default["default"].info(
        `Parsing all metadata... ${colors__default["default"].bold(colors__default["default"].red("[FORCE]"))}`
      );
    } else {
      consola__default["default"].info("Parsing all metadata...");
    }
    await Promise.all([googleFontMetadata.fetchAPI(finalKey), googleFontMetadata.fetchVariable()]);
    await googleFontMetadata.parsev1(options.force, true);
    await googleFontMetadata.parsev2(options.force, true);
    await googleFontMetadata.generateAxis();
    await googleFontMetadata.parseVariable(true);
    await googleFontMetadata.parseIcons(options.force);
    await googleFontMetadata.parseLicenses();
  } catch (error) {
    consola__default["default"].error(error);
  }
});
cli.command("build [...fonts]", "Build font packages").option("-f, --force", "Force rebuild all packages").option("-t, --test", "Build test fonts only").option("--ttf", "Include TTF/OTF fonts").action(async (fonts, options) => {
  try {
    consola__default["default"].info(
      `Building packages... ${options.force ? colors__default["default"].bold(colors__default["default"].red("[FORCE]")) : ""}`
    );
    await queue.processGoogle(options, fonts);
    if (options.force) {
      consola__default["default"].info("Rebuilding custom packages...");
      await rebuild();
      consola__default["default"].success("Finished rebuilding custom packages.");
    }
  } catch (error) {
    consola__default["default"].error(error);
  }
});
cli.command("create").action(async () => {
  try {
    await queue.create();
  } catch (error) {
    consola__default["default"].error(error);
  }
});
cli.command("create-verify").option("-i, --id <id>", "ID of the font to verify").option("--cwd <cwd>", "Directory to run verification in").option("--ci", "Run in CI mode and throw errors instead of fancy prompts").option("--all", "Verify all fonts").action(async (options) => {
  try {
    if (options.all) {
      await queue.verifyAll();
      consola__default["default"].success("All packages valid.");
    } else {
      await queue.verify({ font: options.id, ci: options.ci, cwd: options.cwd });
    }
  } catch (error) {
    consola__default["default"].error(error);
  }
});
cli.command("create-rebuild").option("--cwd <cwd>", "Directory to run rebuild in").action(async (options) => {
  try {
    consola__default["default"].info("Rebuilding custom packages...");
    await rebuild({ cwd: options.cwd });
    consola__default["default"].success("Finished rebuilding custom packages.");
  } catch (error) {
    consola__default["default"].error(error);
  }
});
cli.help();
cli.version(version);
cli.parse();
