#!/usr/bin/env node
import 'dotenv/config';
import { cac } from 'cac';
import consola$1, { consola } from 'consola';
import { fetchAPI, fetchVariable, parsev1, parsev2, generateAxis, parseVariable, parseIcons, parseLicenses } from 'google-font-metadata';
import colors from 'picocolors';
import { g as getDirectories, b as buildCustom, a as verifyAll, p as processGoogle, c as create, v as verify } from './queue-98cf87c3.mjs';
import fs from 'fs-extra';
import path__default from 'pathe';
import '@clack/prompts';
import 'json-stringify-pretty-compact';
import '@fontsource-utils/generate';
import 'node:fs';
import 'p-queue';

var version = "0.3.13";

const getMetadata = async (dir) => {
  return await fs.readJson(path__default.join(dir, "metadata.json"), "utf8");
};
const getPackageJson = async (dir) => {
  return await fs.readJson(path__default.join(dir, "package.json"), "utf8");
};
const rebuild = async (opts) => {
  const dir = "./fonts/other";
  const directories = getDirectories(dir, opts?.cwd);
  for (const directory of directories) {
    const fontDir = path__default.join(opts?.cwd ?? process.cwd(), dir, directory);
    const metadata = await getMetadata(fontDir);
    const pkgJson = await getPackageJson(fontDir);
    const files = await fs.readdir(fontDir);
    for (const file of files) {
      if (file !== "files" && file !== "LICENSE") {
        await fs.remove(path__default.join(fontDir, file));
      }
    }
    await buildCustom(metadata, {
      dir,
      version: pkgJson.version,
      publishHash: pkgJson.publishHash
    });
    consola.info(`Rebuilt ${metadata.id}.`);
  }
  await verifyAll();
};

const cli = cac("fontsource");
cli.command("fetch [key]", "Fetch parsing metadata for all fonts").option("-f, --force", "Force parse all metadata").action(async (key, options) => {
  try {
    const finalKey = key ?? process.env.GOOGLE_API_KEY;
    if (!finalKey) {
      throw new Error("No API key provided.");
    }
    if (options.force) {
      consola$1.info(
        `Parsing all metadata... ${colors.bold(colors.red("[FORCE]"))}`
      );
    } else {
      consola$1.info("Parsing all metadata...");
    }
    await Promise.all([fetchAPI(finalKey), fetchVariable()]);
    await parsev1(options.force, true);
    await parsev2(options.force, true);
    await generateAxis();
    await parseVariable(true);
    await parseIcons(options.force);
    await parseLicenses();
  } catch (error) {
    consola$1.error(error);
  }
});
cli.command("build [...fonts]", "Build font packages").option("-f, --force", "Force rebuild all packages").option("-t, --test", "Build test fonts only").option("--ttf", "Include TTF/OTF fonts").action(async (fonts, options) => {
  try {
    consola$1.info(
      `Building packages... ${options.force ? colors.bold(colors.red("[FORCE]")) : ""}`
    );
    await processGoogle(options, fonts);
    if (options.force) {
      consola$1.info("Rebuilding custom packages...");
      await rebuild();
      consola$1.success("Finished rebuilding custom packages.");
    }
  } catch (error) {
    consola$1.error(error);
  }
});
cli.command("create").action(async () => {
  try {
    await create();
  } catch (error) {
    consola$1.error(error);
  }
});
cli.command("create-verify").option("-i, --id <id>", "ID of the font to verify").option("--cwd <cwd>", "Directory to run verification in").option("--ci", "Run in CI mode and throw errors instead of fancy prompts").option("--all", "Verify all fonts").action(async (options) => {
  try {
    if (options.all) {
      await verifyAll();
      consola$1.success("All packages valid.");
    } else {
      await verify({ font: options.id, ci: options.ci, cwd: options.cwd });
    }
  } catch (error) {
    consola$1.error(error);
  }
});
cli.command("create-rebuild").option("--cwd <cwd>", "Directory to run rebuild in").action(async (options) => {
  try {
    consola$1.info("Rebuilding custom packages...");
    await rebuild({ cwd: options.cwd });
    consola$1.success("Finished rebuilding custom packages.");
  } catch (error) {
    consola$1.error(error);
  }
});
cli.help();
cli.version(version);
cli.parse();
